@@ -1,4 +1,4 @@
-// Copyright(C) 1999-2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-2024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
@@ -8,13 +8,12 @@
 #include "apr_util.h"
 #include "aprepro.h"        // for Aprepro, symrec, file_rec, etc
 #include "aprepro_parser.h" // for Parser, Parser::token, etc
-#include "terminal_color.h"
-#if defined(FMT_SUPPORT)
-#include <fmt/ostream.h>
-#endif
 #include <cstdio>
-#include <cstdlib>  // for exit, EXIT_SUCCESS, etc
-#include <cstring>  // for strcmp
+#include <cstdlib> // for exit, EXIT_SUCCESS, etc
+#include <cstring> // for strcmp
+#include <fmt/color.h>
+#include <fmt/format.h>
+#include <fmt/ostream.h>
 #include <fstream>  // for operator<<, basic_ostream, etc
 #include <iomanip>  // for operator<<, setw, etc
 #include <iostream> // for left, cerr, cout, streampos
@@ -34,8 +33,8 @@
 #endif
 
 namespace {
-  const std::string version_short{"6.25"};
-  const std::string version_date{"(2023/10/12)"};
+  const std::string version_short{"6.32"};
+  const std::string version_date{"(2024/05/20)"};
   const std::string version_string = version_short + " " + version_date;
 
   void output_copyright();
@@ -223,27 +222,19 @@ namespace SEAMS {
 
   void Aprepro::error(const std::string &msg, bool line_info, bool prefix) const
   {
-    bool              colorize = (errorStream == &std::cerr) && isatty(fileno(stderr));
-    std::stringstream ss;
-    if (prefix) {
-      if (colorize) {
-        (*errorStream) << trmclr::red;
-      }
-      (*errorStream) << "Aprepro-" << short_version() << ": ERROR: ";
-    }
+    bool        colorize = (errorStream == &std::cerr) && isatty(fileno(stderr));
+    std::string message  = prefix ? fmt::format("Aprepro-{}: ERROR: {}", short_version(), msg)
+                                  : fmt::format("{}", msg);
+    std::string lines    = line_info ? fmt::format(" ({}, line {})", ap_file_list.top().name,
+                                                   ap_file_list.top().lineno)
+                                     : "";
 
-    ss << msg;
-    if (prefix && colorize) {
-      ss << trmclr::normal;
+    if (colorize) {
+      fmt::print(*errorStream, "{}{}\n", fmt::styled(message, fmt::fg(fmt::color::red)), lines);
     }
-
-    if (line_info) {
-      ss << " (" << ap_file_list.top().name << ", line " << ap_file_list.top().lineno << ")";
+    else {
+      fmt::print(*errorStream, "{}{}\n", message, lines);
     }
-    ss << "\n";
-
-    // Send it to the user defined stream
-    (*errorStream) << ss.str();
     parseErrorCount++;
   }
 
@@ -253,28 +244,20 @@ namespace SEAMS {
       return;
     }
 
-    bool              colorize = (warningStream == &std::cerr) && isatty(fileno(stderr));
-    std::stringstream ss;
-    if (prefix) {
-      if (colorize) {
-        (*warningStream) << trmclr::yellow;
-      }
-      (*warningStream) << "Aprepro: WARNING: ";
+    bool        colorize = (warningStream == &std::cerr) && isatty(fileno(stderr));
+    std::string message =
+        prefix ? fmt::format("Aprepro: WARNING: {}", msg) : fmt::format("{}", msg);
+    std::string lines = line_info ? fmt::format(" ({}, line {})", ap_file_list.top().name,
+                                                ap_file_list.top().lineno)
+                                  : "";
+
+    if (colorize) {
+      fmt::print(*warningStream, "{}{}\n", fmt::styled(message, fmt::fg(fmt::color::yellow)),
+                 lines);
     }
-
-    ss << msg;
-
-    if (prefix && colorize) {
-      ss << trmclr::normal;
+    else {
+      fmt::print(*warningStream, "{}{}\n", message, lines);
     }
-
-    if (line_info) {
-      ss << " (" << ap_file_list.top().name << ", line " << ap_file_list.top().lineno << ")";
-    }
-    ss << "\n";
-
-    // Send it to the user defined stream
-    (*warningStream) << ss.str();
     parseWarningCount++;
   }
 
@@ -284,27 +267,18 @@ namespace SEAMS {
       return;
     }
 
-    bool              colorize = (infoStream == &std::cout) && isatty(fileno(stdout));
-    std::stringstream ss;
-    if (prefix) {
-      if (colorize) {
-        (*infoStream) << trmclr::blue;
-      }
-      (*infoStream) << "Aprepro: INFO: ";
-    }
-    ss << msg;
+    bool        colorize = (infoStream == &std::cout) && isatty(fileno(stdout));
+    std::string message  = prefix ? fmt::format("Aprepro: INFO: {}", msg) : fmt::format("{}", msg);
+    std::string lines    = line_info ? fmt::format(" ({}, line {})", ap_file_list.top().name,
+                                                   ap_file_list.top().lineno)
+                                     : "";
 
-    if (prefix && colorize) {
-      ss << trmclr::normal;
+    if (colorize) {
+      fmt::print(*infoStream, "{}{}\n", fmt::styled(message, fmt::fg(fmt::color::blue)), lines);
     }
-
-    if (line_info) {
-      ss << " (" << ap_file_list.top().name << ", line " << ap_file_list.top().lineno << ")";
+    else {
+      fmt::print(*infoStream, "{}{}\n", message, lines);
     }
-    ss << "\n";
-
-    // Send it to the user defined stream
-    (*infoStream) << ss.str();
   }
 
   void Aprepro::set_error_streams(std::ostream *c_error, std::ostream *c_warning,
@@ -635,12 +609,7 @@ namespace SEAMS {
           << "            --info=file: Output INFO messages (e.g. DUMP() output) to file.\n"
           << "      --nowarning or -W: Do not print WARN messages              \n"
           << "  --comment=char or -c=char: Change comment character to 'char'  \n"
-#if defined(FMT_SUPPORT)
           << "    --full_precision -p: Floating point output uses as many digits as needed.\n"
-#else
-          << "    --full_precision -p: (Not supported in this build) Floating point output uses as "
-             "many digits as needed.\n"
-#endif
           << "      --copyright or -C: Print copyright message                 \n"
           << "   --keep_history or -k: Keep a history of aprepro substitutions.\n"
           << "                         (not for general interactive use)       \n"
@@ -813,13 +782,8 @@ namespace SEAMS {
     for (const auto &ptr : get_sorted_sym_table()) {
       if (!ptr->isInternal) {
         if (ptr->type == Parser::token::VAR || ptr->type == Parser::token::IMMVAR) {
-#if defined(FMT_SUPPORT)
           fmt::print((*infoStream), "{}{}\": {}", (first ? "\"" : ",\n\""), ptr->name,
                      ptr->value.var);
-#else
-          (*infoStream) << (first ? "\"" : ",\n\"") << ptr->name << "\": " << std::setprecision(10)
-                        << ptr->value.var;
-#endif
           first = false;
         }
         else if (ptr->type == Parser::token::UNDVAR) {
@@ -853,23 +817,12 @@ namespace SEAMS {
         if (spre.empty() || ptr->name.find(spre) != std::string::npos) {
           if (doInternal == ptr->isInternal) {
             if (ptr->type == Parser::token::VAR) {
-#if defined(FMT_SUPPORT)
               fmt::print((*infoStream), "{}  {{{:<{}}\t= {}}}\n", comment, ptr->name, width,
                          ptr->value.var);
-#else
-              (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name
-                            << "\t= " << std::setprecision(10) << ptr->value.var << "}" << '\n';
-#endif
             }
             else if (ptr->type == Parser::token::IMMVAR) {
-#if defined(FMT_SUPPORT)
               fmt::print((*infoStream), "{}  {{{:<{}}\t= {}}} (immutable)\n", comment, ptr->name,
                          width, ptr->value.var);
-#else
-              (*infoStream) << comment << "  {" << std::left << std::setw(width) << ptr->name
-                            << "\t= " << std::setprecision(10) << ptr->value.var << "} (immutable)"
-                            << '\n';
-#endif
             }
             else if (ptr->type == Parser::token::SVAR) {
               if (strchr(ptr->value.svar.c_str(), '\n') != nullptr ||
@@ -906,33 +859,35 @@ namespace SEAMS {
     else if (type == Parser::token::FNCT || type == Parser::token::SFNCT ||
              type == Parser::token::AFNCT) {
       int fwidth = 20; // controls spacing/padding for the function names
-      (*infoStream) << trmclr::blue << "\nFunctions returning double:" << trmclr::normal << '\n';
+      fmt::print(*infoStream, "{}",
+                 fmt::styled("\nFunctions returning double:\n", fmt::fg(fmt::color::cyan)));
       for (const auto &ptr : get_sorted_sym_table()) {
         if (spre.empty() || ptr->name.find(spre) != std::string::npos) {
           if (ptr->type == Parser::token::FNCT) {
-            (*infoStream) << std::left << trmclr::green << std::setw(fwidth) << ptr->syntax
-                          << trmclr::normal << ":  " << ptr->info << '\n';
+            fmt::print(*infoStream, "{:<{}}:  {}\n",
+                       fmt::styled(ptr->syntax, fmt::fg(fmt::color::lime)), fwidth, ptr->info);
           }
         }
       }
 
-      (*infoStream) << trmclr::blue << trmclr::blue
-                    << "\nFunctions returning string:" << trmclr::normal << '\n';
+      fmt::print(*infoStream, "{}",
+                 fmt::styled("\nFunctions returning string:\n", fmt::fg(fmt::color::cyan)));
       for (const auto &ptr : get_sorted_sym_table()) {
         if (spre.empty() || ptr->name.find(spre) != std::string::npos) {
           if (ptr->type == Parser::token::SFNCT) {
-            (*infoStream) << std::left << trmclr::green << std::setw(fwidth) << ptr->syntax
-                          << trmclr::normal << ":  " << ptr->info << '\n';
+            fmt::print(*infoStream, "{:<{}}:  {}\n",
+                       fmt::styled(ptr->syntax, fmt::fg(fmt::color::lime)), fwidth, ptr->info);
           }
         }
       }
 
-      (*infoStream) << trmclr::blue << "\nFunctions returning array:" << trmclr::normal << '\n';
+      fmt::print(*infoStream, "{}",
+                 fmt::styled("\nFunctions returning array:\n", fmt::fg(fmt::color::cyan)));
       for (const auto &ptr : get_sorted_sym_table()) {
         if (spre.empty() || ptr->name.find(spre) != std::string::npos) {
           if (ptr->type == Parser::token::AFNCT) {
-            (*infoStream) << std::left << trmclr::green << std::setw(fwidth) << ptr->syntax
-                          << trmclr::normal << ":  " << ptr->info << '\n';
+            fmt::print(*infoStream, "{:<{}}:  {}\n",
+                       fmt::styled(ptr->syntax, fmt::fg(fmt::color::lime)), fwidth, ptr->info);
           }
         }
       }
